@@ -11,7 +11,10 @@ fn main() {
     println!("cargo:rustc-flags=-l dylib=stdc++");
     println!("cargo:rustc-flags=-l dylib=uv");
     println!("cargo:rustc-link-search={}", "/usr/lib/x86_64-linux-gnu");
-    println!("cargo:rustc-link-search={}", "/usr/local/lib/x86_64-linux-gnu");
+    println!(
+        "cargo:rustc-link-search={}",
+        "/usr/local/lib/x86_64-linux-gnu"
+    );
     println!("cargo:rustc-link-search={}", "/usr/local/lib64");
     println!("cargo:rustc-link-search={}", "/usr/local/lib");
     println!("cargo:rustc-link-search={}", "/usr/lib64/");
