@@ -1,16 +1,16 @@
-use cassandra::data_type::ConstDataType;
-use cassandra::statement::Statement;
-use cassandra::util::Protected;
-use cassandra::error::*;
+use crate::cassandra::data_type::ConstDataType;
+use crate::cassandra::error::*;
+use crate::cassandra::statement::Statement;
+use crate::cassandra::util::Protected;
 
-use cassandra_sys::CassPrepared as _PreparedStatement;
-use cassandra_sys::cass_prepared_bind;
-use cassandra_sys::cass_prepared_free;
-use cassandra_sys::cass_prepared_parameter_data_type;
-use cassandra_sys::cass_prepared_parameter_data_type_by_name;
-use cassandra_sys::cass_prepared_parameter_name;
-use std::{mem, slice, str};
+use crate::cassandra_sys::cass_prepared_bind;
+use crate::cassandra_sys::cass_prepared_free;
+use crate::cassandra_sys::cass_prepared_parameter_data_type;
+use crate::cassandra_sys::cass_prepared_parameter_data_type_by_name;
+use crate::cassandra_sys::cass_prepared_parameter_name;
+use crate::cassandra_sys::CassPrepared as _PreparedStatement;
 use std::ffi::CString;
+use std::{mem, slice, str};
 
 /// A statement that has been prepared against at least one Cassandra node.
 /// Instances of this class should not be created directly, but through Session.prepare().
@@ -30,15 +30,23 @@ impl Drop for PreparedStatement {
     }
 }
 
-
 impl Protected<*const _PreparedStatement> for PreparedStatement {
-    fn inner(&self) -> *const _PreparedStatement { self.0 }
-    fn build(inner: *const _PreparedStatement) -> Self { if inner.is_null() { panic!("Unexpected null pointer") }; PreparedStatement(inner) }
+    fn inner(&self) -> *const _PreparedStatement {
+        self.0
+    }
+    fn build(inner: *const _PreparedStatement) -> Self {
+        if inner.is_null() {
+            panic!("Unexpected null pointer")
+        };
+        PreparedStatement(inner)
+    }
 }
 
 impl PreparedStatement {
     /// Creates a bound statement from a pre-prepared statement.
-    pub fn bind(&self) -> Statement { unsafe { Statement::build(cass_prepared_bind(self.0)) } }
+    pub fn bind(&self) -> Statement {
+        unsafe { Statement::build(cass_prepared_bind(self.0)) }
+    }
 
     /// Gets the name of a parameter at the specified index.
     #[allow(cast_possible_truncation)]
@@ -46,11 +54,14 @@ impl PreparedStatement {
         unsafe {
             let mut name = mem::zeroed();
             let mut name_length = mem::zeroed();
-            cass_prepared_parameter_name(self.0, index, &mut name, &mut name_length).to_result(())
+            cass_prepared_parameter_name(self.0, index, &mut name, &mut name_length)
+                .to_result(())
                 .and_then(|_| {
-                    Ok(str::from_utf8(slice::from_raw_parts(name as *const u8, name_length as usize))?)
-                }
-            )
+                    Ok(str::from_utf8(slice::from_raw_parts(
+                        name as *const u8,
+                        name_length as usize,
+                    ))?)
+                })
         }
     }
 
@@ -69,8 +80,10 @@ impl PreparedStatement {
     pub fn parameter_data_type_by_name(&self, name: &str) -> ConstDataType {
         unsafe {
             let name_cstr = CString::new(name).expect("must be utf8");
-            ConstDataType::build(cass_prepared_parameter_data_type_by_name(self.0,
-                                                                    name_cstr.as_ptr()))
+            ConstDataType::build(cass_prepared_parameter_data_type_by_name(
+                self.0,
+                name_cstr.as_ptr(),
+            ))
         }
     }
 }
