@@ -1,34 +1,41 @@
-use cassandra::data_type::ConstDataType;
-use cassandra::iterator::FieldIterator;
-use cassandra::util::Protected;
-use cassandra::value::Value;
-use cassandra::error::*;
+use crate::cassandra::data_type::ConstDataType;
+use crate::cassandra::error::*;
+use crate::cassandra::iterator::FieldIterator;
+use crate::cassandra::util::Protected;
+use crate::cassandra::value::Value;
 
-use cassandra_sys::CASS_OK;
-use cassandra_sys::CassFunctionMeta as _CassFunctionMeta;
-use cassandra_sys::cass_function_meta_argument;
-use cassandra_sys::cass_function_meta_argument_count;
-use cassandra_sys::cass_function_meta_argument_type_by_name;
-use cassandra_sys::cass_function_meta_body;
-use cassandra_sys::cass_function_meta_called_on_null_input;
-use cassandra_sys::cass_function_meta_field_by_name;
-use cassandra_sys::cass_function_meta_full_name;
-use cassandra_sys::cass_function_meta_language;
-use cassandra_sys::cass_function_meta_name;
-use cassandra_sys::cass_function_meta_return_type;
-use cassandra_sys::cass_iterator_fields_from_function_meta;
-use cassandra_sys::cass_true;
+use crate::cassandra_sys::cass_function_meta_argument;
+use crate::cassandra_sys::cass_function_meta_argument_count;
+use crate::cassandra_sys::cass_function_meta_argument_type_by_name;
+use crate::cassandra_sys::cass_function_meta_body;
+use crate::cassandra_sys::cass_function_meta_called_on_null_input;
+use crate::cassandra_sys::cass_function_meta_field_by_name;
+use crate::cassandra_sys::cass_function_meta_full_name;
+use crate::cassandra_sys::cass_function_meta_language;
+use crate::cassandra_sys::cass_function_meta_name;
+use crate::cassandra_sys::cass_function_meta_return_type;
+use crate::cassandra_sys::cass_iterator_fields_from_function_meta;
+use crate::cassandra_sys::cass_true;
+use crate::cassandra_sys::CassFunctionMeta as _CassFunctionMeta;
+use crate::cassandra_sys::CASS_OK;
 
-use std::{mem, slice, str};
 use std::ffi::CString;
+use std::{mem, slice, str};
 
 /// The metadata for a function
 #[derive(Debug)]
 pub struct FunctionMeta(*const _CassFunctionMeta);
 
 impl Protected<*const _CassFunctionMeta> for FunctionMeta {
-    fn inner(&self) -> *const _CassFunctionMeta { self.0 }
-    fn build(inner: *const _CassFunctionMeta) -> Self { if inner.is_null() { panic!("Unexpected null pointer") }; FunctionMeta(inner) }
+    fn inner(&self) -> *const _CassFunctionMeta {
+        self.0
+    }
+    fn build(inner: *const _CassFunctionMeta) -> Self {
+        if inner.is_null() {
+            panic!("Unexpected null pointer")
+        };
+        FunctionMeta(inner)
+    }
 }
 
 impl FunctionMeta {
@@ -44,9 +51,12 @@ impl FunctionMeta {
             let mut name = mem::zeroed();
             let mut name_length = mem::zeroed();
             cass_function_meta_name(self.0, &mut name, &mut name_length);
-            str::from_utf8(slice::from_raw_parts(name as *const u8, name_length as usize))
-                .expect("must be utf8")
-                .to_owned()
+            str::from_utf8(slice::from_raw_parts(
+                name as *const u8,
+                name_length as usize,
+            ))
+            .expect("must be utf8")
+            .to_owned()
         }
     }
 
@@ -59,9 +69,12 @@ impl FunctionMeta {
             let mut name = mem::zeroed();
             let mut name_length = mem::zeroed();
             cass_function_meta_full_name(self.0, &mut name, &mut name_length);
-            str::from_utf8(slice::from_raw_parts(name as *const u8, name_length as usize))
-                .expect("must be utf8")
-                .to_owned()
+            str::from_utf8(slice::from_raw_parts(
+                name as *const u8,
+                name_length as usize,
+            ))
+            .expect("must be utf8")
+            .to_owned()
         }
     }
 
@@ -72,9 +85,12 @@ impl FunctionMeta {
             let mut name = mem::zeroed();
             let mut name_length = mem::zeroed();
             cass_function_meta_body(self.0, &mut name, &mut name_length);
-            str::from_utf8(slice::from_raw_parts(name as *const u8, name_length as usize))
-                .expect("must be utf8")
-                .to_owned()
+            str::from_utf8(slice::from_raw_parts(
+                name as *const u8,
+                name_length as usize,
+            ))
+            .expect("must be utf8")
+            .to_owned()
         }
     }
 
@@ -85,9 +101,12 @@ impl FunctionMeta {
             let mut name = mem::zeroed();
             let mut name_length = mem::zeroed();
             cass_function_meta_language(self.0, &mut name, &mut name_length);
-            str::from_utf8(slice::from_raw_parts(name as *const u8, name_length as usize))
-                .expect("must be utf8")
-                .to_owned()
+            str::from_utf8(slice::from_raw_parts(
+                name as *const u8,
+                name_length as usize,
+            ))
+            .expect("must be utf8")
+            .to_owned()
         }
     }
 
@@ -97,7 +116,9 @@ impl FunctionMeta {
     }
 
     /// Gets the number of arguments this function takes.
-    pub fn argument_count(&self) -> usize { unsafe { cass_function_meta_argument_count(self.0) } }
+    pub fn argument_count(&self) -> usize {
+        unsafe { cass_function_meta_argument_count(self.0) }
+    }
 
     /// Gets the function's argument name and type for the provided index.
     pub fn argument(&self, index: usize) -> Result<()> {
@@ -106,7 +127,8 @@ impl FunctionMeta {
             let mut name_length = mem::zeroed();
             let mut data_type = mem::zeroed();
 
-            cass_function_meta_argument(self.0, index, &mut name, &mut name_length, &mut data_type).to_result(())
+            cass_function_meta_argument(self.0, index, &mut name, &mut name_length, &mut data_type)
+                .to_result(())
         }
     }
 
@@ -115,12 +137,17 @@ impl FunctionMeta {
         unsafe {
             let name_cstr = CString::new(name).expect("must be utf8");
             // TODO: can return NULL
-            ConstDataType::build(cass_function_meta_argument_type_by_name(self.0, name_cstr.as_ptr()))
+            ConstDataType::build(cass_function_meta_argument_type_by_name(
+                self.0,
+                name_cstr.as_ptr(),
+            ))
         }
     }
 
     /// Gets the return type of the function.
-    pub fn return_type(&self) -> ConstDataType { unsafe { ConstDataType::build(cass_function_meta_return_type(self.0)) } }
+    pub fn return_type(&self) -> ConstDataType {
+        unsafe { ConstDataType::build(cass_function_meta_return_type(self.0)) }
+    }
 
     /// Gets a metadata field for the provided name. Metadata fields allow direct
     /// access to the column data found in the underlying "functions" metadata table.
